Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(379)

Unified Diff: media/base/stream_parser.h

Issue 1716503002: Basic media tracks implementation for media stream parsers (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/media_tracks.cc ('k') | media/blink/websourcebuffer_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/stream_parser.h
diff --git a/media/base/stream_parser.h b/media/base/stream_parser.h
index 11740c9d1c6eeb9c67dce7d34de271b3a1c9e99b..4b9fa7f3e4d314f1616907c8bd1d2af16131cb6c 100644
--- a/media/base/stream_parser.h
+++ b/media/base/stream_parser.h
@@ -25,10 +25,9 @@
namespace media {
-class AudioDecoderConfig;
+class MediaTracks;
class StreamParserBuffer;
class TextTrackConfig;
-class VideoDecoderConfig;
// Abstract interface for parsing media byte streams.
class MEDIA_EXPORT StreamParser {
@@ -76,18 +75,17 @@ class MEDIA_EXPORT StreamParser {
typedef base::Callback<void(const InitParameters& params)> InitCB;
// Indicates when new stream configurations have been parsed.
// First parameter - The new audio configuration. If the config is not valid
// then it means that there isn't an audio stream.
// Second parameter - The new video configuration. If the config is not valid
// then it means that there isn't an audio stream.
// Third parameter - The new text tracks configuration. If the map is empty,
// then no text tracks were parsed from the stream.
// Return value - True if the new configurations are accepted.
// False if the new configurations are not supported
// and indicates that a parsing error should be signalled.
- typedef base::Callback<bool(const AudioDecoderConfig&,
- const VideoDecoderConfig&,
- const TextTrackConfigMap&)> NewConfigCB;
+ typedef base::Callback<bool(scoped_ptr<MediaTracks>,
+ const TextTrackConfigMap&)>
+ NewConfigCB;
// New stream buffers have been parsed.
// First parameter - A queue of newly parsed audio buffers.
« no previous file with comments | « media/base/media_tracks.cc ('k') | media/blink/websourcebuffer_impl.h » ('j') | no next file with comments »
@@ -76,18 +75,17 @@ class MEDIA_EXPORT StreamParser {
typedef base::Callback<void(const InitParameters& params)> InitCB;
// Indicates when new stream configurations have been parsed.
- // First parameter - The new audio configuration. If the config is not valid
- // then it means that there isn't an audio stream.
- // Second parameter - The new video configuration. If the config is not valid
- // then it means that there isn't an audio stream.
- // Third parameter - The new text tracks configuration. If the map is empty,
- // then no text tracks were parsed from the stream.
+ // First parameter - An object containing information about media tracks as
+ // well as audio/video decoder configs associated with each
+ // track.
+ // Second parameter - The new text tracks configuration. If the map is empty,
+ // then no text tracks were parsed from the stream.
// Return value - True if the new configurations are accepted.
// False if the new configurations are not supported

Powered by Google App Engine
This is Rietveld 408576698